#
# spec file for package perl-Module-Metadata
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Module-Metadata
Name:           perl-Module-Metadata
Version:        1.000038
Release:        1.7
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Gather package and POD information from perl module files
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/E/ET/ETHER/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(version) >= 0.87
Requires:       perl(version) >= 0.87
%{perl_requires}

%description
This module provides a standard way to gather metadata about a .pm file
through (mostly) static analysis and (some) code execution. When
determining the version of a module, the '$VERSION' assignment is 'eval'ed,
as is traditional in the CPAN toolchain.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING README
%license LICENCE

%changelog
* Sat Apr 29 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.000038
  see /usr/share/doc/packages/perl-Module-Metadata/Changes
  1.000038  2023-04-28 11:25:40Z
  - detects "class" syntax
* Sun Sep  8 2019 <timueller+perl@suse.de>
- updated to 1.000037
  see /usr/share/doc/packages/perl-Module-Metadata/Changes
  1.000037  2019-09-07 18:32:44Z
  - add decode_pod option for automatic =encoding handling
* Sat Apr 20 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.000036
  see /usr/share/doc/packages/perl-Module-Metadata/Changes
  1.000036  2019-04-18 18:25:15Z
  - properly clean up temp dirs after testing
* Thu Apr 18 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.000035
  see /usr/share/doc/packages/perl-Module-Metadata/Changes
  1.000035  2019-04-18 02:43:11Z
  - quieten noisy tests (issue #31)
  1.000034  2018-07-19 20:26:18Z (TRIAL RELEASE)
  - fix how relative paths are absolutized, so they work properly on MSWin32
    (Christian Walde, PR#24)
* Tue Jul 26 2016 coolo@suse.com
- updated to 1.000033
  see /usr/share/doc/packages/perl-Module-Metadata/Changes
  1.000033  2016-07-24 23:32:58Z
  - fix file operation in tests for VMS
  1.000032  2016-04-23 22:36:24Z (TRIAL RELEASE)
  - use a more strict matching heuristic when attempting to infer the
    "primary" module name in a parsed .pm file
  - only report "main" as the module name if code was seen outside another
    namespace, fixing bad results for pod files (RT#107525)
  1.000031  2015-11-24 03:57:55Z (TRIAL RELEASE)
  - be less noisy on failure when building as part of perl core (see perl
    RT#126685)
  1.000030  2015-11-20 03:03:24Z (TRIAL RELEASE)
  - temp dirs cleaned up during tests (Steve Hay)
  - more accurately mark tests as TODO, so as to have a quieter and less
    confusing test run without passing TODO tests. This release is primarily
    intended for the perl 5.23.5 release.
  1.000029  2015-09-11 16:25:43Z (TRIAL RELEASE)
  - fix missing "use" statement in refactored test helper (only affected older
    perls, due to other module interactions)
  1.000028  2015-09-11 04:24:39Z (TRIAL RELEASE)
  - refactored and expanded test cases
  - fixed a $VERSION extraction issue on perl 5.6.2 (RT#105978, PR#17)
  - fix the detection of package Foo when $Foo::VERSION is set (RT#85961)
* Sun May 10 2015 lars@linux-schulserver.de
- build require perl(Test::More) >= 0.82
* Mon Apr 13 2015 coolo@suse.com
- updated to 1.000027
  see /usr/share/doc/packages/perl-Module-Metadata/Changes
  1.000027  2015-04-11 00:21:26Z
  - work around issues with an unconfigured Log::Contextual (Kent Fredric)
  - allow tests to pass in a perl with no taint support (James Raspass)
* Sat Feb  7 2015 dnh@opensuse.org
- update to 1.000026
  1.000026  2015-01-17 19:22:34Z
  - patched tests to be less noisy in blead builds (Dave Mitchell, RT#101491)
  1.000025  2015-01-04 18:56:00Z
  - evaluate version assignment in a clean environment, to fix assignment in a
    block (RT#101095)
  1.000024  2014-06-03 01:52:46Z
  - fix inaccurate prerequisite declaration on Test::More (in 1.000023)
  1.000023  2014-06-02 02:37:17Z
  - support installations on older perls with an ExtUtils::MakeMaker earlier
    than 6.63_03
  1.000022 - 2014-04-29
  - work around change in comparison behaviour in Test::More 0.95_01 by being
    more explicit with our tests - now explicitly checking the string form of
    the extracted version, rather than the entire version object
  - ensure the extracted version is returned as a version object in all cases
    (RT#87782, Randy Stauner)
  1.000021 - 2014-04-29
  - fix use of newer interface from File::Path, to avoid another prereq on
    older perls (Graham Knop, PR#7)
  - fixed all out of date prereq declarations
  1.000020 - 2014-04-27
  - new is_indexable() object method (ether, RT#84357)
  - eliminated dependency on IO::File (and by virtue, XS) - thanks, leont!
  - removed cruft in test infrastructure left behind from separation from
    Module::Build (ether)
  - repository moved to https://github.com/Perl-Toolchain-Gang/Module-Metadata
  - .pm file is now wholly ascii, for nicer fatpacking (RT#95086)
  - some code micro-optimizations (Olivier Mengué, PR#4)
* Fri Jan 17 2014 lars@linux-schulserver.de
- update to 1.000019:
  - warnings now disabled inside during the evaluation of generated version
    sub (BinGOs, RT#89282)
  - detaint version, if needed (RT#88576, Chris Williams)
  - Change wording about safety/security to satisfy CVE-2013-1437
  - Remove "now installs to 'site' for perl 5.12+" from last version
  - Fix reliance on recent Test::Builder
  - Make tests perl 5.6 compatible
  - now installs to 'site' for perl 5.12+, as per p5p recommendation
  - improved package detection heuristics (thanks, Edward Zborowski!)
  - fix ->contains_pod (RT#84932, Tokuhiro Matsuno)
  - fix detection of pod after __END__ (RT79656, Tokuhiro Matsuno)
  - Performance improvement: the creation of a Module::Metadata object
    for a typical module file has been sped up by about 40%% (VPIT)
  - Fix t/metadata.t failure under Cygwin (JDHEDDEN)
  - Portability fix-ups for new_from_module() and test failures on VMS (CBERRY)
* Sat Jul 14 2012 chris@computersalat.de
- initial package 1.000009
  * created by cpanspec 1.78.03
